MokaPlayer
==========

Features
--------

-  Support all the most popular music file formats
-  Gapless playback
-  Resumes playback on startup
-  Automatically fetch:

   -  Album covers
   -  Lyrics
   -  ASCII and Guitar Pro tabs

